@@ -109,7 +109,7 @@ sub _connect {
     @options{qw(socks_address socks_port)} = @options{qw(address port)};
     ($proto, @options{qw(address port)}) = $t->endpoint($tx);
     my $userinfo = $tx->req->via_proxy(0)->proxy->userinfo;
-    @options{qw(socks_user socks_pass)} = split ':', $userinfo if $userinfo;
+    @options{qw(socks_user socks_pass)} = split /:/, $userinfo if $userinfo;
   }
 
   # TLS
